diff hr2_manager.pl @ 1:e2cbcf6fa22e draft

master branch Updating with tag :CI_COMMIT_TAG - - Fxx
author fgiacomoni
date Sun, 11 Dec 2022 17:16:43 +0000
parents 86296c048e46
children 23970530a518
line wrap: on
line diff
--- a/hr2_manager.pl	Wed Jun 05 09:40:20 2019 -0400
+++ b/hr2_manager.pl	Sun Dec 11 17:16:43 2022 +0000
@@ -3,6 +3,7 @@
 ## script  : hr2_manager.pl
 ## VERSIONS :
 #	- 01/03/2019 : Fix P issue, permit more flexible atom settings and add requirements for conda auto managing.
+#	- 09/12/2022 : Fix "Additional atomes not taken into account" - Ticket issue #7 
 
 #=============================================================================
 #                              Included modules and versions
@@ -47,8 +48,8 @@
 				"mode:s"		=>	\$mode,
 				"charge:i"		=>	\$charge,
 				"regleOr:s"		=>	\$has_golden_rules,
-				"atomes:s"		=>	\$atomes_basic, # [basic atoms like CNOHP]
-				"atomessup:s"	=>	\$atomes,
+				"atomes_basic:s"=>	\$atomes_basic, # [basic atoms like CNOHP]
+				"atomes_sup:s"	=>	\$atomes,
 				"output1:s"		=>	\$output_csv,
 				"outputView:s"	=>	\$output_html,
 				"verbose:i"		=> 	\$verbose,
@@ -190,6 +191,9 @@
 	my ($tbody_object) = $oHtml->set_html_tbody_object( $nb_pages_for_html_out, $CONF->{HTML_ENTRIES_PER_PAGE} ) ;
 	($tbody_object) = $oHtml->add_mz_to_tbody_object($tbody_object, $CONF->{HTML_ENTRIES_PER_PAGE}, $masses, $ids, $parsed_results ) ;
 	($tbody_object) = $oHtml->add_entries_to_tbody_object($tbody_object, $parsed_results) ;
+	
+	print Dumper $tbody_object ;
+	
 	my $html_file = $binPath.'/'.$CONF->{'HTML_TEMPLATE'} ;
 	my $output = $oHtml->write_html_skel(\$output_html, $tbody_object, $nb_pages_for_html_out, $search_condition, $html_file, $CONF->{'JS_GALAXY_PATH'}, $CONF->{'CSS_GALAXY_PATH'}) ;
 	
@@ -270,15 +274,15 @@
 
 # hr2_manager is a script to elucide chemical formula by their accurate masses. The HiRes program is integrate in this package
 # Input : a accurate mass or a file of masses
 # Author : Franck Giacomoni and Marion Landi
 # Email : fgiacomoni\@clermont.inra.fr or mlandi\@clermont.inra.fr
 # Version : 1.1
 # Created : 01/12/2011
-# Last Update : 09032014
+# Last Update : 06/12/2022
 USAGE :		 
 		hr2_manager.pl -h or
 		hr2_manager.pl -input [cvs file of masses] -colId [int] -colmass [int] -nbHeader [int] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atome [P, S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
-		hr2_manager.pl -masse [double] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atome [P, S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
+		hr2_manager.pl -masse [double] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atomes_basic [C, N, O, P, H ] -atomes_sup [S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
 	" ;
 	exit(1);
 }
@@ -294,8 +298,8 @@
 =head1 USAGE
 
  hr2_manager.pl -h or
- hr2_manager.pl -input [cvs file of masses] -colId [int] -colmass [int] -nbHeader [int] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atome [P, S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
- hr2_manager.pl -masse [double] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atome [P, S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
+ hr2_manager.pl -input [cvs file of masses] -colId [int] -colmass [int] -nbHeader [int] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atomes_basic [C, N, O, P, H ] -atomes_sup [S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
+ hr2_manager.pl -masse [double] -tolerance [float] -mode [positive, neutral or negative] -charge [int] -regleOr [yes or no] -atomes_basic [C, N, O, P, H ] -atomes_sup [S, F, Cl, K, B, A, 1 ] -output1 [csv file] -outputView [html file]
 
 =head1 SYNOPSIS
 
@@ -315,8 +319,9 @@
 
 =head1 AUTHOR
 
-Franck Giacomoni E<lt>franck.giacomoni@clermont.inra.frE<gt>
-Marion Landi E<lt>marion.landi@clermont.inra.frE<gt>
+Franck Giacomoni E<lt>franck.giacomoni@inrae.frE<gt>
+Marion Landi E<lt>marion.landi@inrae.frE<gt>
+Lain Pavot E<lt>lain.pavot@inrae.frE<gt>
 
 =head1 LICENSE
 
@@ -332,4 +337,6 @@
 
 version 4 : 01/03/2019
 
+version 5 : 09/12/2022
+
 =cut
\ No newline at end of file
@@ -270,15 +274,15 @@
 # hr2_manager is a script to elucide chemical formula by their accurate masses. The HiRes program is integrate in this package
 # Input : a accurate mass or a file of masses
-# Author : Franck Giacomoni and Marion Landi
-# Email : fgiacomoni\@clermont.inra.fr or mlandi\@clermont.inra.fr
-# Version : 1.1
+# Authors : Lain Pavot, Marion Landi and Franck Giacomoni
+# Email : franck.giacomoni\@inrae.fr
+# Version : 1.1.2
 # Created : 01/12/2011